#region Using declarations
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using System.Windows.Media;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Core;
using NinjaTrader.Gui;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Gui.SuperDom;
using NinjaTrader.Gui.Tools;
using NinjaTrader.Data;
using NinjaTrader.NinjaScript;
using NinjaTrader.Core.FloatingPoint;
using NinjaTrader.NinjaScript.DrawingTools;
using SharpDX.DirectWrite;

#endregion

//This namespace holds Indicators in this folder and is required. Do not change it. 
namespace NinjaTrader.NinjaScript.Indicators
{
	public class RKRiskRuler : Indicator
	{
		private Point			clickPoint	= new Point();
		private bool			clickSet	= false;

		private double			myStop 		= 0;
		private double			myEntry 	= 0;
		private double			myR1 		= 0;
		private double			myR2 		= 0;
		private double			myR3 		= 0;
		private double			myRisk		= 0;
		private double			myTarget1	= 0;
		private double			myTarget2	= 0;
		private double			myTarget3	= 0;
		private int				barIdx 		= 0;
		private int				barPrev 	= 0;

		private System.Windows.Media.Brush	stopBrush;
		private System.Windows.Media.Brush	entryBrush;
		private System.Windows.Media.Brush	r1Brush;
		private System.Windows.Media.Brush	r2Brush;
		private System.Windows.Media.Brush	r3Brush;

		protected override void OnStateChange()
		{
			if (State == State.SetDefaults)
			{
				Description									= @"Draws lines for Stop, Entry, R1, R2 and R3 on middle Mouse-Click";
				Name										= "RKRiskRuler";
				Calculate									= Calculate.OnBarClose;
				IsOverlay									= true;
				DisplayInDataBox							= false;
				DrawOnPricePanel							= true;
				DrawHorizontalGridLines						= true;
				DrawVerticalGridLines						= true;
				PaintPriceMarkers							= false;
				ScaleJustification							= NinjaTrader.Gui.Chart.ScaleJustification.Right;
				//Disable this property if your indicator requires custom values that cumulate with each new market data event. 
				//See Help Guide for additional information.
				IsSuspendedWhileInactive					= true;
				StopBrush 									= System.Windows.Media.Brushes.Red;
				EntryBrush									= System.Windows.Media.Brushes.DodgerBlue;
				R1Brush										= System.Windows.Media.Brushes.Green;
				R2Brush										= System.Windows.Media.Brushes.DarkGreen;
				R3Brush										= System.Windows.Media.Brushes.OliveDrab;
				StopWidth									= 2;
				EntryWidth									= 2;
				R1Width										= 2;
				R2Width										= 2;
				R3Width										= 2;
				RulerWidth									= 8;
				StopAdjustTicks								= 1;
				EntryAdjustTicks							= 1;
				MaxRiskTicks								= 0;
				ShowR2										= true;
				ShowR3										= false;
				ShowTicks									= true;
			}
			else if (State == State.Configure)
			{
			}
			else if (State == State.Historical)
			{
				//SetZOrder(-1); // default here is go below the bars and called in State.Historical
				SetZOrder(int.MaxValue); //move to front
			}
			else if (State == State.DataLoaded)
			{
					ChartControl.ChartPanels[0].MouseDown += MiddleMouseButtonExample_MouseDown;
			}
			else if (State == State.Terminated)
			{
				if (ChartControl != null)
					ChartControl.ChartPanels[0].MouseDown -= MiddleMouseButtonExample_MouseDown;
			}
		}

		protected override void OnBarUpdate() {}

		public void MiddleMouseButtonExample_MouseDown(object sender, MouseButtonEventArgs e)
		{
			if (e.MiddleButton == MouseButtonState.Pressed)
			{
				// convert e.GetPosition for different dpi settings
				clickPoint.X = ChartingExtensions.ConvertToHorizontalPixels(e.GetPosition(ChartPanel as IInputElement).X, ChartControl.PresentationSource);
				clickPoint.Y = ChartingExtensions.ConvertToVerticalPixels(e.GetPosition(ChartPanel as IInputElement).Y, ChartControl.PresentationSource);

				if (clickPoint.Y > 0)
				{
					clickSet = true;
					barIdx = -1;
				}
				// trigger the chart invalidate so that the render loop starts even if there is no data being received
				ChartControl.InvalidateVisual();
				e.Handled = true;
			}
		}

		protected override void OnRender(ChartControl chartControl, ChartScale chartScale)
		{
			float	startY		= -1;
			float	startX		= -1;
			float	endX		= -1;
			string	myText		= "";

			// Set text to chart label color and font
			TextFormat	textFormat			= chartControl.Properties.LabelFont.ToDirectWriteTextFormat();

			// if the click is set we have a dpi converted x and y position.
			// create the rendering object in OnRender so that any brushes used are created for the renderTarget
			if (clickSet)
			{
				if (barIdx < 0)
				{
					int clickPixelX 	= (int)clickPoint.X;
					int clickPixelY 	= (int)clickPoint.Y;
					double valueClick	= chartScale.GetValueByY(clickPixelY);
					barIdx 				= ChartBars.GetBarIdxByX(chartControl, clickPixelX);
					
					if (barIdx == barPrev) {
						clickSet = false;
						myStop = 0;
						myEntry = 0;
						myR1 = 0;
						myR2 = 0;
						myR3 = 0;
						barPrev = 0;
					} else {
						barPrev = barIdx;
				
						if (valueClick>=(High.GetValueAt(barIdx)+Low.GetValueAt(barIdx))/2)
						{
							// Long
							myStop = Low.GetValueAt(barIdx) - (StopAdjustTicks*Instrument.MasterInstrument.TickSize);
							myEntry = High.GetValueAt(barIdx) + (EntryAdjustTicks*Instrument.MasterInstrument.TickSize);
							myRisk =  (myEntry - myStop) / Instrument.MasterInstrument.TickSize;
							myR1 = myEntry + (1 * (myEntry - myStop));
							myR2 = myEntry + (2 * (myEntry - myStop));
							myR3 = myEntry + (3 * (myEntry - myStop));
							myTarget1 =  (myR1 - myEntry) / Instrument.MasterInstrument.TickSize;
							myTarget2 =  (myR2 - myEntry) / Instrument.MasterInstrument.TickSize;
							myTarget3 =  (myR3 - myEntry) / Instrument.MasterInstrument.TickSize;
							
						} else {
							//Short
							myEntry = Low.GetValueAt(barIdx) - (EntryAdjustTicks*Instrument.MasterInstrument.TickSize);
							myStop = High.GetValueAt(barIdx) + (StopAdjustTicks*Instrument.MasterInstrument.TickSize);
							myRisk =  (myStop - myEntry) / Instrument.MasterInstrument.TickSize;
							myR1 = myEntry - (1 * (myStop - myEntry));
							myR2 = myEntry - (2 * (myStop - myEntry));
							myR3 = myEntry - (3 * (myStop - myEntry));
							myTarget1 =  (myEntry - myR1) / Instrument.MasterInstrument.TickSize;
							myTarget2 =  (myEntry - myR2) / Instrument.MasterInstrument.TickSize;
							myTarget3 =  (myEntry - myR3) / Instrument.MasterInstrument.TickSize;
						}
					}
				}
				
				if (myStop>0) {
					startX		= chartControl.GetXByBarIndex(ChartBars, barIdx);
					endX		= chartControl.GetXByBarIndex(ChartBars, barIdx + RulerWidth);
					
					// draw stop line
					startY		= chartScale.GetYByValue(myStop);
					SharpDX.Vector2 stopStart = new SharpDX.Vector2(startX, startY);
					SharpDX.Vector2 stopEnd = new SharpDX.Vector2(endX, startY);
					SharpDX.Direct2D1.Brush stopBrushDx;
					stopBrushDx	= stopBrush.ToDxBrush(RenderTarget);
					RenderTarget.DrawLine(stopStart, stopEnd, stopBrushDx, StopWidth);  

					// Draw Risk-Text
					myText = (myRisk == 1) ? "-" + myRisk + " tick"	: "-" + myRisk + " ticks";
					if (MaxRiskTicks > 0)
					{
						myText = (myRisk > MaxRiskTicks) ? "*** No !!! " + myText + " ***" : myText;
					}
					if (ShowTicks || (myRisk > MaxRiskTicks && MaxRiskTicks > 0))
					{
						TextLayout stopLayout = new TextLayout(Globals.DirectWriteFactory, myText, textFormat, 200, textFormat.FontSize);
						RenderTarget.DrawTextLayout(stopStart, stopLayout, stopBrushDx);
						stopLayout.Dispose();
					}
					stopBrushDx.Dispose();
					
					// draw entry line
					startY		= chartScale.GetYByValue(myEntry);
					SharpDX.Vector2 entryStart = new SharpDX.Vector2(startX, startY);
					SharpDX.Vector2 entryEnd = new SharpDX.Vector2(endX, startY);
					SharpDX.Direct2D1.Brush entryBrushDx;
					entryBrushDx	= entryBrush.ToDxBrush(RenderTarget);
					RenderTarget.DrawLine(entryStart, entryEnd, entryBrushDx, EntryWidth);  
					entryBrushDx.Dispose();

					// draw R1 line
					startY		= chartScale.GetYByValue(myR1);
					SharpDX.Vector2 r1Start = new SharpDX.Vector2(startX, startY);
					SharpDX.Vector2 r1End = new SharpDX.Vector2(endX, startY);
					SharpDX.Direct2D1.Brush r1BrushDx;
					r1BrushDx	= r1Brush.ToDxBrush(RenderTarget);
					RenderTarget.DrawLine(r1Start, r1End, r1BrushDx, R1Width);  

					// Draw target-text for R1
					if (ShowTicks)
					{
						//myText = (myTarget1 == 1) ? "+" + myTarget1 + " tick"	: "+" + myTarget1 + " ticks";
						myText = "+" + myTarget1;
						TextLayout r1Layout = new TextLayout(Globals.DirectWriteFactory, myText, textFormat, 200, textFormat.FontSize);
						RenderTarget.DrawTextLayout(r1Start, r1Layout, r1BrushDx);
						r1Layout.Dispose();
					}
					r1BrushDx.Dispose();

					// draw R2 line
					if (ShowR2) 
					{
						startY		= chartScale.GetYByValue(myR2);
						
						SharpDX.Vector2 r2Start = new SharpDX.Vector2(startX, startY);
						SharpDX.Vector2 r2End = new SharpDX.Vector2(endX, startY);
						SharpDX.Direct2D1.Brush r2BrushDx;
						r2BrushDx	= r2Brush.ToDxBrush(RenderTarget);
						RenderTarget.DrawLine(r2Start, r2End, r2BrushDx, R2Width);  

						// Draw target-text for R2
						if (ShowTicks)
						{
							//myText = (myTarget2 == 1) ? "+" + myTarget2 + " tick"	: "+" + myTarget2 + " ticks";
							myText = "+" + myTarget2;
							TextLayout r2Layout = new TextLayout(Globals.DirectWriteFactory, myText, textFormat, 200, textFormat.FontSize);
							RenderTarget.DrawTextLayout(r2Start, r2Layout, r2BrushDx);
							r2Layout.Dispose();
						}
						r2BrushDx.Dispose();
					}

					// draw R3 line
					if (ShowR3) 
					{
						startY		= chartScale.GetYByValue(myR3);
						
						SharpDX.Vector2 r3Start = new SharpDX.Vector2(startX, startY);
						SharpDX.Vector2 r3End = new SharpDX.Vector2(endX, startY);
						SharpDX.Direct2D1.Brush r3BrushDx;
						r3BrushDx	= r3Brush.ToDxBrush(RenderTarget);
						RenderTarget.DrawLine(r3Start, r3End, r3BrushDx, R3Width);  

						// Draw target-text for R3
						if (ShowTicks)
						{
							//myText = (myTarget3 == 1) ? "+" + myTarget3 + " tick"	: "+" + myTarget3 + " ticks";
							myText = "+" + myTarget3;
							TextLayout r3Layout = new TextLayout(Globals.DirectWriteFactory, myText, textFormat, 200, textFormat.FontSize);
							RenderTarget.DrawTextLayout(r3Start, r3Layout, r3BrushDx);
							r3Layout.Dispose();
						}
						r3BrushDx.Dispose();
					}

				}
			}
			textFormat.Dispose();
		}

		#region Properties
		[NinjaScriptProperty]
		[XmlIgnore]
		[Display(ResourceType = typeof(Custom.Resource), Name = "Color Stop", Description="Stop level", Order=1, GroupName = "Lines")]
		public System.Windows.Media.Brush StopBrush
		{
			get { return stopBrush; }
			set { stopBrush = value; }
		}

		[Browsable(false)]
		public string StopBrushSerialize
		{
			get { return Serialize.BrushToString(StopBrush); }
			set { StopBrush = Serialize.StringToBrush(value); }
		}


		[NinjaScriptProperty]
		[XmlIgnore]
		[Display(ResourceType = typeof(Custom.Resource), Name = "Color Entry", Description="Entry level", Order=2, GroupName = "Lines")]
		public System.Windows.Media.Brush EntryBrush
		{
			get { return entryBrush; }
			set { entryBrush = value; }
		}

		[Browsable(false)]
		public string EntryBrushSerialize
		{
			get { return Serialize.BrushToString(EntryBrush); }
			set { EntryBrush = Serialize.StringToBrush(value); }
		}

		[NinjaScriptProperty]
		[XmlIgnore]
		[Display(ResourceType = typeof(Custom.Resource), Name = "Color 1x Risk", Description="1x Risk", Order=3, GroupName = "Lines")]
		public System.Windows.Media.Brush R1Brush
		{
			get { return r1Brush; }
			set { r1Brush = value; }
		}

		[Browsable(false)]
		public string r1BrushSerialize
		{
			get { return Serialize.BrushToString(r1Brush); }
			set { r1Brush = Serialize.StringToBrush(value); }
		}

		[NinjaScriptProperty]
		[XmlIgnore]
		[Display(ResourceType = typeof(Custom.Resource), Name = "Color 2x Risk", Description="2x Risk", Order=4, GroupName = "Lines")]
		public System.Windows.Media.Brush R2Brush
		{
			get { return r2Brush; }
			set { r2Brush = value; }
		}

		[Browsable(false)]
		public string r2BrushSerialize
		{
			get { return Serialize.BrushToString(r2Brush); }
			set { r2Brush = Serialize.StringToBrush(value); }
		}

		[NinjaScriptProperty]
		[XmlIgnore]
		[Display(ResourceType = typeof(Custom.Resource), Name = "Color 3x Risk", Description="3x Risk", Order=5, GroupName = "Lines")]
		public System.Windows.Media.Brush R3Brush
		{
			get { return r3Brush; }
			set { r3Brush = value; }
		}

		[Browsable(false)]
		public string r3BrushSerialize
		{
			get { return Serialize.BrushToString(r3Brush); }
			set { r3Brush = Serialize.StringToBrush(value); }
		}

		[NinjaScriptProperty]
		[Range(1, int.MaxValue)]
		[Display(Name="Width Stop", Description="Width of Stop line", Order=6, GroupName="Lines")]
		public int StopWidth
		{ get; set; }

		[NinjaScriptProperty]
		[Range(1, int.MaxValue)]
		[Display(Name="Width Entry", Description="Width of Entry-line", Order=7, GroupName="Lines")]
		public int EntryWidth
		{ get; set; }

		[NinjaScriptProperty]
		[Range(1, int.MaxValue)]
		[Display(Name="Width 1x Risk", Description="Width of 1x Risk", Order=8, GroupName="Lines")]
		public int R1Width
		{ get; set; }

		[NinjaScriptProperty]
		[Range(1, int.MaxValue)]
		[Display(Name="Width 2x Risk", Description="Width of 2x Risk", Order=9, GroupName="Lines")]
		public int R2Width
		{ get; set; }

		[NinjaScriptProperty]
		[Range(1, int.MaxValue)]
		[Display(Name="Width 3x Risk", Description="Width of 3x Risk", Order=10, GroupName="Lines")]
		public int R3Width
		{ get; set; }

		[NinjaScriptProperty]
		[Range(1, int.MaxValue)]
		[Display(Name="Ruler Width #Bars", Description="Width of displayed lines (in # of bars)", Order=11, GroupName="Ruler")]
		public int RulerWidth
		{ get; set; }

		[NinjaScriptProperty]
		[Range(0, int.MaxValue)]
		[Display(Name="Stop adjust Ticks", Description="Number of extra ticks between Bar and Stop Line", Order=12, GroupName="Ruler")]
		public int StopAdjustTicks
		{ get; set; }

		[NinjaScriptProperty]
		[Range(0, int.MaxValue)]
		[Display(Name="Entry adjust Ticks", Description="Number of extra ticks between Bar and Entry-line", Order=13, GroupName="Ruler")]
		public int EntryAdjustTicks
		{ get; set; }

		[NinjaScriptProperty]
		[Range(0, int.MaxValue)]
		[Display(Name="Max. Risk Ticks", Description="Max. acceptable risk in ticks (display warning if exceeded)", Order=14, GroupName="Ruler")]
		public int MaxRiskTicks
		{ get; set; }

		[NinjaScriptProperty]
		[Display(Name="Show 2x Risk", Description="Show R2-line", Order=15, GroupName="Ruler")]
		public bool ShowR2
		{ get; set; }

		[NinjaScriptProperty]
		[Display(Name="Show 3x Risk", Description="Show R3-line", Order=16, GroupName="Ruler")]
		public bool ShowR3
		{ get; set; }

		[NinjaScriptProperty]
		[Display(Name="Show Ticks", Description="Show Ticks", Order=17, GroupName="Ruler")]
		public bool ShowTicks
		{ get; set; }



		#endregion

	}
}

#region NinjaScript generated code. Neither change nor remove.

namespace NinjaTrader.NinjaScript.Indicators
{
	public partial class Indicator : NinjaTrader.Gui.NinjaScript.IndicatorRenderBase
	{
		private RKRiskRuler[] cacheRKRiskRuler;
		public RKRiskRuler RKRiskRuler(System.Windows.Media.Brush stopBrush, System.Windows.Media.Brush entryBrush, System.Windows.Media.Brush r1Brush, System.Windows.Media.Brush r2Brush, System.Windows.Media.Brush r3Brush, int stopWidth, int entryWidth, int r1Width, int r2Width, int r3Width, int rulerWidth, int stopAdjustTicks, int entryAdjustTicks, int maxRiskTicks, bool showR2, bool showR3, bool showTicks)
		{
			return RKRiskRuler(Input, stopBrush, entryBrush, r1Brush, r2Brush, r3Brush, stopWidth, entryWidth, r1Width, r2Width, r3Width, rulerWidth, stopAdjustTicks, entryAdjustTicks, maxRiskTicks, showR2, showR3, showTicks);
		}

		public RKRiskRuler RKRiskRuler(ISeries<double> input, System.Windows.Media.Brush stopBrush, System.Windows.Media.Brush entryBrush, System.Windows.Media.Brush r1Brush, System.Windows.Media.Brush r2Brush, System.Windows.Media.Brush r3Brush, int stopWidth, int entryWidth, int r1Width, int r2Width, int r3Width, int rulerWidth, int stopAdjustTicks, int entryAdjustTicks, int maxRiskTicks, bool showR2, bool showR3, bool showTicks)
		{
			if (cacheRKRiskRuler != null)
				for (int idx = 0; idx < cacheRKRiskRuler.Length; idx++)
					if (cacheRKRiskRuler[idx] != null && cacheRKRiskRuler[idx].StopBrush == stopBrush && cacheRKRiskRuler[idx].EntryBrush == entryBrush && cacheRKRiskRuler[idx].R1Brush == r1Brush && cacheRKRiskRuler[idx].R2Brush == r2Brush && cacheRKRiskRuler[idx].R3Brush == r3Brush && cacheRKRiskRuler[idx].StopWidth == stopWidth && cacheRKRiskRuler[idx].EntryWidth == entryWidth && cacheRKRiskRuler[idx].R1Width == r1Width && cacheRKRiskRuler[idx].R2Width == r2Width && cacheRKRiskRuler[idx].R3Width == r3Width && cacheRKRiskRuler[idx].RulerWidth == rulerWidth && cacheRKRiskRuler[idx].StopAdjustTicks == stopAdjustTicks && cacheRKRiskRuler[idx].EntryAdjustTicks == entryAdjustTicks && cacheRKRiskRuler[idx].MaxRiskTicks == maxRiskTicks && cacheRKRiskRuler[idx].ShowR2 == showR2 && cacheRKRiskRuler[idx].ShowR3 == showR3 && cacheRKRiskRuler[idx].ShowTicks == showTicks && cacheRKRiskRuler[idx].EqualsInput(input))
						return cacheRKRiskRuler[idx];
			return CacheIndicator<RKRiskRuler>(new RKRiskRuler(){ StopBrush = stopBrush, EntryBrush = entryBrush, R1Brush = r1Brush, R2Brush = r2Brush, R3Brush = r3Brush, StopWidth = stopWidth, EntryWidth = entryWidth, R1Width = r1Width, R2Width = r2Width, R3Width = r3Width, RulerWidth = rulerWidth, StopAdjustTicks = stopAdjustTicks, EntryAdjustTicks = entryAdjustTicks, MaxRiskTicks = maxRiskTicks, ShowR2 = showR2, ShowR3 = showR3, ShowTicks = showTicks }, input, ref cacheRKRiskRuler);
		}
	}
}

namespace NinjaTrader.NinjaScript.MarketAnalyzerColumns
{
	public partial class MarketAnalyzerColumn : MarketAnalyzerColumnBase
	{
		public Indicators.RKRiskRuler RKRiskRuler(System.Windows.Media.Brush stopBrush, System.Windows.Media.Brush entryBrush, System.Windows.Media.Brush r1Brush, System.Windows.Media.Brush r2Brush, System.Windows.Media.Brush r3Brush, int stopWidth, int entryWidth, int r1Width, int r2Width, int r3Width, int rulerWidth, int stopAdjustTicks, int entryAdjustTicks, int maxRiskTicks, bool showR2, bool showR3, bool showTicks)
		{
			return indicator.RKRiskRuler(Input, stopBrush, entryBrush, r1Brush, r2Brush, r3Brush, stopWidth, entryWidth, r1Width, r2Width, r3Width, rulerWidth, stopAdjustTicks, entryAdjustTicks, maxRiskTicks, showR2, showR3, showTicks);
		}

		public Indicators.RKRiskRuler RKRiskRuler(ISeries<double> input , System.Windows.Media.Brush stopBrush, System.Windows.Media.Brush entryBrush, System.Windows.Media.Brush r1Brush, System.Windows.Media.Brush r2Brush, System.Windows.Media.Brush r3Brush, int stopWidth, int entryWidth, int r1Width, int r2Width, int r3Width, int rulerWidth, int stopAdjustTicks, int entryAdjustTicks, int maxRiskTicks, bool showR2, bool showR3, bool showTicks)
		{
			return indicator.RKRiskRuler(input, stopBrush, entryBrush, r1Brush, r2Brush, r3Brush, stopWidth, entryWidth, r1Width, r2Width, r3Width, rulerWidth, stopAdjustTicks, entryAdjustTicks, maxRiskTicks, showR2, showR3, showTicks);
		}
	}
}

namespace NinjaTrader.NinjaScript.Strategies
{
	public partial class Strategy : NinjaTrader.Gui.NinjaScript.StrategyRenderBase
	{
		public Indicators.RKRiskRuler RKRiskRuler(System.Windows.Media.Brush stopBrush, System.Windows.Media.Brush entryBrush, System.Windows.Media.Brush r1Brush, System.Windows.Media.Brush r2Brush, System.Windows.Media.Brush r3Brush, int stopWidth, int entryWidth, int r1Width, int r2Width, int r3Width, int rulerWidth, int stopAdjustTicks, int entryAdjustTicks, int maxRiskTicks, bool showR2, bool showR3, bool showTicks)
		{
			return indicator.RKRiskRuler(Input, stopBrush, entryBrush, r1Brush, r2Brush, r3Brush, stopWidth, entryWidth, r1Width, r2Width, r3Width, rulerWidth, stopAdjustTicks, entryAdjustTicks, maxRiskTicks, showR2, showR3, showTicks);
		}

		public Indicators.RKRiskRuler RKRiskRuler(ISeries<double> input , System.Windows.Media.Brush stopBrush, System.Windows.Media.Brush entryBrush, System.Windows.Media.Brush r1Brush, System.Windows.Media.Brush r2Brush, System.Windows.Media.Brush r3Brush, int stopWidth, int entryWidth, int r1Width, int r2Width, int r3Width, int rulerWidth, int stopAdjustTicks, int entryAdjustTicks, int maxRiskTicks, bool showR2, bool showR3, bool showTicks)
		{
			return indicator.RKRiskRuler(input, stopBrush, entryBrush, r1Brush, r2Brush, r3Brush, stopWidth, entryWidth, r1Width, r2Width, r3Width, rulerWidth, stopAdjustTicks, entryAdjustTicks, maxRiskTicks, showR2, showR3, showTicks);
		}
	}
}

#endregion
